@@ -322,7 +322,6 @@ static void seg_xform_rel(double *x, double *y) {}
         case 52:  /* select normalization transformation */
         case 53:  /* set clipping indicator */
         case 108: /* set resample method */
-        case 109: /* set resize behaviour */
         case 207: /* set border color index */
         case 208: /* select clipping transformation */
         case 211: /* set clip region */
@@ -339,13 +338,15 @@ static void seg_xform_rel(double *x, double *y) {}
         case 28:  /* set character expansion factor */
         case 29:  /* set character spacing */
         case 31:  /* set character height */
+        case 109: /* set nominal size */
         case 200: /* set text slant */
         case 203: /* set transparency */
         case 206: /* set border width */
           RESOLVE(f_arr_1, double, sizeof(double));
           break;
 
-        case 32: /* set character up vector */
+        case 32:  /* set character up vector */
+        case 212: /* set clip sector */
           RESOLVE(f_arr_1, double, sizeof(double));
           RESOLVE(f_arr_2, double, sizeof(double));
           break;
@@ -391,14 +392,8 @@ static void seg_xform_rel(double *x, double *y) {}
 
           p->width = [self bounds].size.width;
           p->height = [self bounds].size.height;
-          if (gkss->resize_behaviour == GKS_K_RESIZE)
-            {
-              p->nominal_size = min(p->width, p->height) / 500.0;
-            }
-          else
-            {
-              p->nominal_size = 1;
-            }
+          p->nominal_size = min(p->width, p->height) / 500.0;
+          if (gkss->nominal_size > 0) p->nominal_size *= gkss->nominal_size;
 
           p->swidth = NSMaxX([[[NSScreen screens] objectAtIndex:0] frame]);
           p->sheight = NSMaxY([[[NSScreen screens] objectAtIndex:0] frame]);
@@ -591,7 +586,9 @@ static void seg_xform_rel(double *x, double *y) {}
           break;
 
         case 109:
-          gkss->resize_behaviour = i_arr[0];
+          gkss->nominal_size = f_arr_1[0];
+          p->nominal_size = min(p->width, p->height) / 500.0;
+          if (gkss->nominal_size > 0) p->nominal_size *= gkss->nominal_size;
           break;
 
         case 200:
@@ -637,6 +634,11 @@ static void seg_xform_rel(double *x, double *y) {}
         case 211:
           gkss->clip_region = i_arr[0];
           break;
+
+        case 212:
+          gkss->clip_start_angle = f_arr_1[0];
+          gkss->clip_end_angle = f_arr_2[0];
+          break;
         }
 
       RESOLVE(len, int, sizeof(int));
@@ -683,6 +685,8 @@ static void seg_xform_rel(double *x, double *y) {}
       double scale = [self.window backingScaleFactor];
       c = (CGContextRef)[[NSGraphicsContext currentContext] graphicsPort];
 
+      NSSize boundsSizeBefore = self.bounds.size;
+
       layer = CGLayerCreateWithContext(c, CGSizeMake(self.bounds.size.width * scale, self.bounds.size.height * scale),
                                        NULL);
       context = CGLayerGetContext(layer);
@@ -705,6 +709,7 @@ static void seg_xform_rel(double *x, double *y) {}
         }
 
       [self interp:buffer];
+      NSSize boundsSizeAfter = self.bounds.size;
       CGContextDrawLayerInRect(c, CGRectMake(0, 0, self.bounds.size.width, self.bounds.size.height), layer);
 
       CGContextFlush(context);
@@ -715,9 +720,23 @@ static void seg_xform_rel(double *x, double *y) {}
 
       context = (CGContextRef)[contextStack lastObject];
       layer = (CGLayerRef)[layerStack lastObject];
+
+      if (boundsSizeBefore.width != boundsSizeAfter.width || boundsSizeBefore.height != boundsSizeAfter.height)
+        {
+          [NSTimer scheduledTimerWithTimeInterval:0.0f
+                                           target:self
+                                         selector:@selector(setNeedsDisplayAfterResize)
+                                         userInfo:nil
+                                          repeats:NO];
+        }
     }
 }
 
+- (void)setNeedsDisplayAfterResize
+{
+  [self setNeedsDisplay:YES];
+}
+
 - (void)setDisplayList:(id)display_list
 {
   int len = [display_list length];
@@ -1107,10 +1126,8 @@ static void seg_xform_rel(double *x, double *y) {}
 
       p->width = width;
       p->height = height;
-      if (gkss->resize_behaviour == GKS_K_RESIZE)
-        {
-          p->nominal_size = min(p->width, p->height) / 500.0;
-        }
+      p->nominal_size = min(p->width, p->height) / 500.0;
+      if (gkss->nominal_size > 0) p->nominal_size *= gkss->nominal_size;
 
       [self setNeedsDisplay:YES];
       [[self window] setFrame:rect display:YES];
@@ -1133,8 +1150,33 @@ static void begin_context(CGContextRef context)
   if (gkss->clip_region == GKS_K_REGION_ELLIPSE && (gkss->clip_tnr != 0 || gkss->clip == GKS_K_CLIP))
     {
       CGMutablePathRef path = CGPathCreateMutable();
-      CGPathAddEllipseInRect(path, NULL, clipRect);
-      CGContextAddPath(context, path);
+      if (gkss->clip_start_angle > 0 || gkss->clip_end_angle < 360)
+        {
+          double a1, a2, x, y, start_x, start_y, end_x, end_y, w, h;
+
+          a1 = gkss->clip_start_angle * M_PI / 180;
+          a2 = gkss->clip_end_angle * M_PI / 180;
+          w = clipRect.size.width;
+          h = clipRect.size.height;
+          x = clipRect.origin.x + w * 0.5;
+          y = clipRect.origin.y + h * 0.5;
+          start_x = x + w * cos(a1);
+          start_y = y + h * sin(a1);
+          end_x = x + w * cos(a2);
+          end_y = y + h * sin(a2);
+
+          CGAffineTransform m = CGAffineTransformMakeTranslation(x, y);
+          m = CGAffineTransformConcat(CGAffineTransformMakeScale(1.0, h / w), m);
+          CGPathAddArc(path, &m, 0, 0, 0.5 * w, a1, a2, a1 > a2);
+          CGPathAddLineToPoint(path, &m, 0, 0);
+          CGContextAddPath(context, path);
+          CGContextClosePath(context);
+        }
+      else
+        {
+          CGPathAddEllipseInRect(path, NULL, clipRect);
+          CGContextAddPath(context, path);
+        }
       CGContextClip(context);
       CGPathRelease(path);
     }
@@ -1446,7 +1488,7 @@ static void draw_pattern(int index, int coli, CGPathRef shape, CGContextRef cont
 {
   double scale;
 
-  if (gkss->resize_behaviour == GKS_K_RESIZE)
+  if (gkss->nominal_size > 0)
     {
       scale = 0.125 * (int)(p->c + p->a) / 125;
     }
