@@ -68,6 +68,7 @@ static char *format[] = {
     "setcharup:ff",
     "setclip:i",
     "setclipregion:i",
+    "setclipsector:ff",
     "setcolormap:i",
     "setcolorrep:ifff",
     "setfillcolorind:i",
@@ -80,11 +81,11 @@ static char *format[] = {
     "setmarkersize:f",
     "setmarkertype:i",
     "setmathfont:i",
+    "setnominalsize:f",
     "setorthographicprojection:ffffff",
     "setperspectiveprojection:fff",
     "setpicturesizeforvolume:ii",
     "setprojectiontype:i",
-    "setresizebehaviour:i",
     "setscale:i",
     "setscalefactors3d:fff",
     "setspace:ffii",
@@ -443,154 +444,157 @@ static void gr(int id)
       gr_setclipregion(i_arg[0]);
       break;
     case 48:
-      gr_setcolormap(i_arg[0]);
+      gr_setclipsector(f_arg[0], f_arg[1]);
       break;
     case 49:
-      gr_setcolorrep(i_arg[0], f_arg[0], f_arg[1], f_arg[2]);
+      gr_setcolormap(i_arg[0]);
       break;
     case 50:
-      gr_setfillcolorind(i_arg[0]);
+      gr_setcolorrep(i_arg[0], f_arg[0], f_arg[1], f_arg[2]);
       break;
     case 51:
-      gr_setfillintstyle(i_arg[0]);
+      gr_setfillcolorind(i_arg[0]);
       break;
     case 52:
-      gr_setfillstyle(i_arg[0]);
+      gr_setfillintstyle(i_arg[0]);
       break;
     case 53:
-      gr_setlinecolorind(i_arg[0]);
+      gr_setfillstyle(i_arg[0]);
       break;
     case 54:
-      gr_setlinetype(i_arg[0]);
+      gr_setlinecolorind(i_arg[0]);
       break;
     case 55:
-      gr_setlinewidth(f_arg[0]);
+      gr_setlinetype(i_arg[0]);
       break;
     case 56:
-      gr_setmarkercolorind(i_arg[0]);
+      gr_setlinewidth(f_arg[0]);
       break;
     case 57:
-      gr_setmarkersize(f_arg[0]);
+      gr_setmarkercolorind(i_arg[0]);
       break;
     case 58:
-      gr_setmarkertype(i_arg[0]);
+      gr_setmarkersize(f_arg[0]);
       break;
     case 59:
-      gr_setmathfont(i_arg[0]);
+      gr_setmarkertype(i_arg[0]);
       break;
     case 60:
-      gr_setorthographicprojection(f_arg[0], f_arg[1], f_arg[2], f_arg[3], f_arg[4], f_arg[5]);
+      gr_setmathfont(i_arg[0]);
       break;
     case 61:
-      gr_setperspectiveprojection(f_arg[0], f_arg[1], f_arg[2]);
+      gr_setnominalsize(f_arg[0]);
       break;
     case 62:
-      gr_setpicturesizeforvolume(i_arg[0], i_arg[1]);
+      gr_setorthographicprojection(f_arg[0], f_arg[1], f_arg[2], f_arg[3], f_arg[4], f_arg[5]);
       break;
     case 63:
-      gr_setprojectiontype(i_arg[0]);
+      gr_setperspectiveprojection(f_arg[0], f_arg[1], f_arg[2]);
       break;
     case 64:
-      gr_setresizebehaviour(i_arg[0]);
+      gr_setpicturesizeforvolume(i_arg[0], i_arg[1]);
       break;
     case 65:
-      gr_setscale(i_arg[0]);
+      gr_setprojectiontype(i_arg[0]);
       break;
     case 66:
-      gr_setscalefactors3d(f_arg[0], f_arg[1], f_arg[2]);
+      gr_setscale(i_arg[0]);
       break;
     case 67:
-      gr_setspace(f_arg[0], f_arg[1], i_arg[0], i_arg[1]);
+      gr_setscalefactors3d(f_arg[0], f_arg[1], f_arg[2]);
       break;
     case 68:
-      gr_setspace3d(f_arg[0], f_arg[1], f_arg[2], f_arg[3]);
+      gr_setspace(f_arg[0], f_arg[1], i_arg[0], i_arg[1]);
       break;
     case 69:
-      gr_settextalign(i_arg[0], i_arg[1]);
+      gr_setspace3d(f_arg[0], f_arg[1], f_arg[2], f_arg[3]);
       break;
     case 70:
-      gr_settextcolorind(i_arg[0]);
+      gr_settextalign(i_arg[0], i_arg[1]);
       break;
     case 71:
-      gr_settextencoding(i_arg[0]);
+      gr_settextcolorind(i_arg[0]);
       break;
     case 72:
-      gr_settextfontprec(i_arg[0], i_arg[1]);
+      gr_settextencoding(i_arg[0]);
       break;
     case 73:
-      gr_settextoffset(f_arg[0], f_arg[1]);
+      gr_settextfontprec(i_arg[0], i_arg[1]);
       break;
     case 74:
-      gr_settextpath(i_arg[0]);
+      gr_settextoffset(f_arg[0], f_arg[1]);
       break;
     case 75:
-      gr_setthreadnumber(i_arg[0]);
+      gr_settextpath(i_arg[0]);
       break;
     case 76:
-      gr_settitles3d(s_arg[0], s_arg[1], s_arg[2]);
+      gr_setthreadnumber(i_arg[0]);
       break;
     case 77:
+      gr_settitles3d(s_arg[0], s_arg[1], s_arg[2]);
+      break;
+    case 78:
       gr_settransformationparameters(f_arg[0], f_arg[1], f_arg[2], f_arg[3], f_arg[4], f_arg[5], f_arg[6], f_arg[7],
                                      f_arg[8]);
       break;
-    case 78:
+    case 79:
       gr_settransparency(f_arg[0]);
       break;
-    case 79:
+    case 80:
       gr_setviewport(f_arg[0], f_arg[1], f_arg[2], f_arg[3]);
       break;
-    case 80:
+    case 81:
       gr_setvolumebordercalculation(i_arg[0]);
       break;
-    case 81:
+    case 82:
       gr_setwindow(f_arg[0], f_arg[1], f_arg[2], f_arg[3]);
       break;
-    case 82:
+    case 83:
       gr_setwindow3d(f_arg[0], f_arg[1], f_arg[2], f_arg[3], f_arg[4], f_arg[5]);
       break;
-    case 83:
+    case 84:
       gr_setwsviewport(f_arg[0], f_arg[1], f_arg[2], f_arg[3]);
       break;
-    case 84:
+    case 85:
       gr_setwswindow(f_arg[0], f_arg[1], f_arg[2], f_arg[3]);
       break;
-    case 85:
+    case 86:
       gr_shadelines(i_arg[0], f_arr[0], f_arr[1], i_arg[1], i_arg[2], i_arg[3]);
       break;
-    case 86:
+    case 87:
       gr_shadepoints(i_arg[0], f_arr[0], f_arr[1], i_arg[1], i_arg[2], i_arg[3]);
       break;
-    case 87:
+    case 88:
       gr_spline(i_arg[0], f_arr[0], f_arr[1], i_arg[1], i_arg[2]);
       break;
-    case 88:
+    case 89:
       gr_surface(i_arg[0], i_arg[1], f_arr[0], f_arr[1], f_arr[2], i_arg[2]);
       break;
-    case 89:
+    case 90:
       gr_text(f_arg[0], f_arg[1], s_arg[0]);
       break;
-    case 90:
+    case 91:
       gr_textext(f_arg[0], f_arg[1], s_arg[0]);
       break;
-    case 91:
+    case 92:
       gr_textx(f_arg[0], f_arg[1], s_arg[0], i_arg[0]);
       break;
-    case 92:
+    case 93:
       gr_titles3d(s_arg[0], s_arg[1], s_arg[2]);
       break;
-    case 93:
+    case 94:
       gr_tricontour(i_arg[0], f_arr[0], f_arr[1], f_arr[2], i_arg[2], f_arr[3]);
       break;
-    case 94:
+    case 95:
       gr_trisurface(i_arg[0], f_arr[0], f_arr[1], f_arr[2]);
       break;
-    case 95:
+    case 96:
       gr_unselectcontext();
       break;
-    case 96:
+    case 97:
       gr_uselinespec(s_arg[0]);
       break;
-    case 97:
+    case 98:
       gr_verrorbars(i_arg[0], f_arr[0], f_arr[1], f_arr[2], f_arr[3]);
       break;
     }
