@@ -11,6 +11,12 @@ GRM::Element::Element(std::string local_name, const std::shared_ptr<GRM::Documen
 {
 }
 
+GRM::Element::~Element()
+{
+  auto cleanup_element = ownerDocument()->getElementCleanupFct();
+  if (cleanup_element) cleanup_element(*this);
+}
+
 std::string GRM::Element::nodeName() const
 {
   return tagName();
@@ -23,7 +29,7 @@ std::string GRM::Element::id() const
 
 std::string GRM::Element::tagName() const
 {
-  return GRM::toupper(this->m_local_name);
+  return GRM::toUpper(this->m_local_name);
 }
 
 std::string GRM::Element::localName() const
@@ -47,158 +53,147 @@ std::unordered_set<std::string> GRM::Element::getAttributeNames() const
   return keys;
 }
 
-GRM::Value GRM::Element::getAttribute(const std::string &qualifiedName) const
+GRM::Value GRM::Element::getAttribute(const std::string &qualified_name) const
 {
-  if (!this->hasAttribute(qualifiedName)) return {};
-  return this->m_attributes.at(qualifiedName);
+  if (!this->hasAttribute(qualified_name)) return {};
+  return this->m_attributes.at(qualified_name);
 }
 
-void GRM::Element::setAttribute(const std::string &qualifiedName, const GRM::Value &value)
+void GRM::Element::setAttribute(const std::string &qualified_name, const GRM::Value &value)
 {
   GRM::Value old_value;
   void (*render)() = nullptr;
   void (*update)(const std::shared_ptr<GRM::Element> &, const std::string &, const std::string &) = nullptr;
-  void (*contextUpdate)(const std::shared_ptr<GRM::Element> &, const std::string &, const GRM::Value &) = nullptr;
-  void (*contextDelete)(const std::shared_ptr<GRM::Element> &) = nullptr;
+  void (*context_update)(const std::shared_ptr<GRM::Element> &, const std::string &, const GRM::Value &) = nullptr;
+  void (*context_delete)(const std::shared_ptr<GRM::Element> &) = nullptr;
   ownerDocument()->getUpdateFct(&render, &update);
-  ownerDocument()->getContextFct(&contextDelete, &contextUpdate);
+  ownerDocument()->getContextFct(&context_delete, &context_update);
 
-  if (hasAttribute(qualifiedName)) old_value = this->m_attributes[qualifiedName];
+  if (hasAttribute(qualified_name)) old_value = this->m_attributes[qualified_name];
 
-  this->m_attributes[qualifiedName] = value;
+  this->m_attributes[qualified_name] = value;
   if (value != old_value)
     {
       auto elem_p = std::static_pointer_cast<Element>(shared_from_this());
-      if (contextUpdate) contextUpdate(elem_p, qualifiedName, old_value);
-      if (qualifiedName == "kind")
+      if (context_update) context_update(elem_p, qualified_name, old_value);
+      if (qualified_name == "kind")
         {
           ;
         }
-      if (qualifiedName == "viewport_x_min" || qualifiedName == "viewport_x_max" || qualifiedName == "viewport_y_min" ||
-          qualifiedName == "viewport_y_max")
+      if (qualified_name == "viewport_x_min" || qualified_name == "viewport_x_max" ||
+          qualified_name == "viewport_y_min" || qualified_name == "viewport_y_max")
         {
-          if (update) update(elem_p, qualifiedName, std::to_string(static_cast<double>(old_value)));
+          if (update) update(elem_p, qualified_name, std::to_string(static_cast<double>(old_value)));
+        }
+      else if (qualified_name == "polar_with_pan")
+        {
+          if (update) update(elem_p, qualified_name, std::to_string(static_cast<int>(old_value)));
         }
       else
         {
-          if (update) update(elem_p, qualifiedName, static_cast<std::string>(old_value));
+          if (update) update(elem_p, qualified_name, static_cast<std::string>(old_value));
         }
       if (render) render();
     }
 }
 
-void GRM::Element::setAttribute(const std::string &qualifiedName, const std::string &value)
+void GRM::Element::setAttribute(const std::string &qualified_name, const std::string &value)
 {
-  setAttribute(qualifiedName, GRM::Value(value));
+  setAttribute(qualified_name, GRM::Value(value));
 }
 
-void GRM::Element::setAttribute(const std::string &qualifiedName, const double &value)
+void GRM::Element::setAttribute(const std::string &qualified_name, const double &value)
 {
-  setAttribute(qualifiedName, GRM::Value(value));
+  setAttribute(qualified_name, GRM::Value(value));
 }
 
-void GRM::Element::setAttribute(const std::string &qualifiedName, const int &value)
+void GRM::Element::setAttribute(const std::string &qualified_name, const int &value)
 {
-  setAttribute(qualifiedName, GRM::Value(value));
+  setAttribute(qualified_name, GRM::Value(value));
 }
 
-void GRM::Element::removeAttribute(const std::string &qualifiedName)
+void GRM::Element::removeAttribute(const std::string &qualified_name)
 {
-  this->m_attributes.erase(qualifiedName);
+  this->m_attributes.erase(qualified_name);
 }
 
-bool GRM::Element::toggleAttribute(const std::string &qualifiedName)
+bool GRM::Element::toggleAttribute(const std::string &qualified_name)
 {
-  bool has_attribute = hasAttribute(qualifiedName);
+  bool has_attribute = hasAttribute(qualified_name);
   if (has_attribute)
     {
-      removeAttribute(qualifiedName);
+      removeAttribute(qualified_name);
     }
   else
     {
-      setAttribute(qualifiedName, "");
+      setAttribute(qualified_name, "");
     }
   return !has_attribute;
 }
 
-bool GRM::Element::toggleAttribute(const std::string &qualifiedName, bool force)
+bool GRM::Element::toggleAttribute(const std::string &qualified_name, bool force)
 {
-  bool has_attribute = hasAttribute(qualifiedName);
+  bool has_attribute = hasAttribute(qualified_name);
   if (force)
     {
-      if (!has_attribute)
-        {
-          setAttribute(qualifiedName, "");
-        }
+      if (!has_attribute) setAttribute(qualified_name, "");
     }
   else
     {
-      if (has_attribute)
-        {
-          removeAttribute(qualifiedName);
-        }
+      if (has_attribute) removeAttribute(qualified_name);
     }
   return force;
 }
 
-bool GRM::Element::hasAttribute(const std::string &qualifiedName) const
+bool GRM::Element::hasAttribute(const std::string &qualified_name) const
 {
-  return this->m_attributes.find(qualifiedName) != GRM::Element::m_attributes.end();
+  return this->m_attributes.find(qualified_name) != m_attributes.end();
 }
 
 template <typename T>
-static std::vector<std::shared_ptr<T>> getElementsByTagName_impl(T &element, const std::string &qualifiedName)
+static std::vector<std::shared_ptr<T>> getElementsByTagNameImpl(T &element, const std::string &qualified_name)
 {
-  std::string local_name = qualifiedName;
+  std::string local_name = qualified_name;
   std::vector<std::shared_ptr<T>> found_elements;
   for (const auto &child_element : element.children())
     {
-      if (local_name == "*" || child_element->localName() == local_name)
-        {
-          found_elements.push_back(child_element);
-        }
-      auto child_found_elements = child_element->getElementsByTagName(qualifiedName);
+      if (local_name == "*" || child_element->localName() == local_name) found_elements.push_back(child_element);
+      auto child_found_elements = child_element->getElementsByTagName(qualified_name);
       found_elements.insert(found_elements.end(), child_found_elements.begin(), child_found_elements.end());
     }
   return found_elements;
 }
 
-std::vector<std::shared_ptr<GRM::Element>> GRM::Element::getElementsByTagName(const std::string &qualifiedName)
+std::vector<std::shared_ptr<GRM::Element>> GRM::Element::getElementsByTagName(const std::string &qualified_name)
 {
-  return getElementsByTagName_impl(*this, qualifiedName);
+  return getElementsByTagNameImpl(*this, qualified_name);
 }
 std::vector<std::shared_ptr<const GRM::Element>>
-GRM::Element::getElementsByTagName(const std::string &qualifiedName) const
+GRM::Element::getElementsByTagName(const std::string &qualified_name) const
 {
-  return getElementsByTagName_impl(*this, qualifiedName);
+  return getElementsByTagNameImpl(*this, qualified_name);
 }
 
-std::vector<std::shared_ptr<GRM::Element>> GRM::Element::getElementsByClassName(const std::string &classNames)
+std::vector<std::shared_ptr<GRM::Element>> GRM::Element::getElementsByClassName(const std::string &class_names)
 {
-  return getElementsByClassName_impl(classNames);
+  return getElementsByClassNameImpl(class_names);
 }
 
 std::vector<std::shared_ptr<const GRM::Element>>
-GRM::Element::getElementsByClassName(const std::string &classNames) const
+GRM::Element::getElementsByClassName(const std::string &class_names) const
 {
-  return getElementsByClassName_impl(classNames);
+  return getElementsByClassNameImpl(class_names);
 }
 
 void GRM::Element::before(std::shared_ptr<GRM::Element> node)
 {
-  if (!parentNode())
-    {
-      throw HierarchyRequestError("element is root node");
-    }
+  if (!parentNode()) throw HierarchyRequestError("element is root node");
   parentNode()->insertBefore(node, shared_from_this());
 }
 
 void GRM::Element::after(std::shared_ptr<GRM::Element> node)
 {
-  if (!parentNode())
-    {
-      throw HierarchyRequestError("element is root node");
-    }
+  if (!parentNode()) throw HierarchyRequestError("element is root node");
   auto next_sibling = nextSibling();
   if (next_sibling)
     {
@@ -212,104 +207,92 @@ void GRM::Element::after(std::shared_ptr<GRM::Element> node)
 
 void GRM::Element::replaceWith(const std::shared_ptr<GRM::Element> &node)
 {
-  if (!parentNode())
-    {
-      throw HierarchyRequestError("element is root node");
-    }
+  if (!parentNode()) throw HierarchyRequestError("element is root node");
   parentNode()->replaceChild(node, shared_from_this());
 }
 
 void GRM::Element::remove()
 {
-  void (*contextUpdate)(const std::shared_ptr<GRM::Element> &, const std::string &, const GRM::Value &) = nullptr;
-  void (*contextDelete)(const std::shared_ptr<GRM::Element> &) = nullptr;
-  ownerDocument()->getContextFct(&contextDelete, &contextUpdate);
+  void (*context_update)(const std::shared_ptr<GRM::Element> &, const std::string &, const GRM::Value &) = nullptr;
+  void (*context_delete)(const std::shared_ptr<GRM::Element> &) = nullptr;
+  ownerDocument()->getContextFct(&context_delete, &context_update);
 
-  if (!parentNode())
-    {
-      throw HierarchyRequestError("element is root node");
-    }
+  if (!parentNode()) throw HierarchyRequestError("element is root node");
 
   auto elem_p = std::static_pointer_cast<Element>(shared_from_this());
-  contextDelete(elem_p);
+  context_delete(elem_p);
 
   parentNode()->removeChild(shared_from_this());
 }
 
 std::vector<std::shared_ptr<GRM::Element>> GRM::Element::children()
 {
-  return children_impl();
+  return childrenImpl();
 }
 
 std::vector<std::shared_ptr<const GRM::Element>> GRM::Element::children() const
 {
-  return children_impl();
+  return childrenImpl();
 }
 
 std::shared_ptr<GRM::Element> GRM::Element::firstChildElement()
 {
-  return firstChildElement_impl();
+  return firstChildElementImpl();
 }
 
 std::shared_ptr<const GRM::Element> GRM::Element::firstChildElement() const
 {
-  return firstChildElement_impl();
+  return firstChildElementImpl();
 }
 
 std::shared_ptr<GRM::Element> GRM::Element::lastChildElement()
 {
-  return lastChildElement_impl();
+  return lastChildElementImpl();
 }
 
 std::shared_ptr<const GRM::Element> GRM::Element::lastChildElement() const
 {
-  return lastChildElement_impl();
+  return lastChildElementImpl();
 }
 
 unsigned long GRM::Element::childElementCount() const
 {
-  return childElementCount_impl();
+  return childElementCountImpl();
 }
 
 void GRM::Element::prepend(const std::vector<std::shared_ptr<GRM::Node>> &nodes)
 {
-  prepend_impl(nodes);
+  prependImpl(nodes);
 }
 
 void GRM::Element::append(const std::vector<std::shared_ptr<GRM::Node>> &nodes)
 {
-  append_impl(nodes);
+  appendImpl(nodes);
 }
 
 void GRM::Element::replaceChildren(const std::vector<std::shared_ptr<GRM::Node>> &nodes)
 {
-  replaceChildren_impl(nodes);
+  replaceChildrenImpl(nodes);
 }
 
-template <typename T> static std::shared_ptr<T> getElementById_impl(std::shared_ptr<T> element, const std::string &id)
+template <typename T> static std::shared_ptr<T> getElementByIdImpl(std::shared_ptr<T> element, const std::string &id)
 {
-  if (element->id() == id)
-    {
-      return element;
-    }
+  if (element->id() == id) return element;
   for (const auto &child_element : element->children())
     {
-      auto child_found_element = getElementById_impl(child_element, id);
-      if (child_found_element)
-        {
-          return child_found_element;
-        }
+      auto child_found_element = getElementByIdImpl(child_element, id);
+      if (child_found_element) return child_found_element;
     }
   return nullptr;
 }
 
 std::shared_ptr<GRM::Element> GRM::Element::getElementById(const std::string &id)
 {
-  return getElementById_impl(shared(), id);
+  return getElementByIdImpl(shared(), id);
 }
 std::shared_ptr<const GRM::Element> GRM::Element::getElementById(const std::string &id) const
 {
-  return getElementById_impl(shared(), id);
+  return getElementByIdImpl(shared(), id);
 }
 
 std::shared_ptr<GRM::Element> GRM::Element::shared()
@@ -329,60 +312,45 @@ std::shared_ptr<GRM::Node> GRM::Element::cloneIndividualNode()
   return element;
 }
 
-bool GRM::Element::isEqualNode(const std::shared_ptr<const GRM::Node> &otherNode) const
+bool GRM::Element::isEqualNode(const std::shared_ptr<const GRM::Node> &other_node) const
 {
-  auto other_node_as_element = std::dynamic_pointer_cast<const GRM::Element>(otherNode);
-  if (!other_node_as_element)
-    {
-      return false;
-    }
-  if (other_node_as_element->localName() != localName())
-    {
-      return false;
-    }
-  if (other_node_as_element->m_attributes.size() != m_attributes.size())
-    {
-      return false;
-    }
+  auto other_node_as_element = std::dynamic_pointer_cast<const GRM::Element>(other_node);
+  if (!other_node_as_element) return false;
+  if (other_node_as_element->localName() != localName()) return false;
+  if (other_node_as_element->m_attributes.size() != m_attributes.size()) return false;
   for (const auto &attribute_entry : other_node_as_element->m_attributes)
     {
-      if (m_attributes.find(attribute_entry.first) == m_attributes.end())
-        {
-          return false;
-        }
-      if (m_attributes.at(attribute_entry.first) != attribute_entry.second)
-        {
-          return false;
-        }
+      if (m_attributes.find(attribute_entry.first) == m_attributes.end()) return false;
+      if (m_attributes.at(attribute_entry.first) != attribute_entry.second) return false;
     }
-  return GRM::Node::children_are_equal_recursive(shared_from_this(), otherNode);
+  return GRM::Node::childrenAreEqualRecursive(shared_from_this(), other_node);
 }
 
 std::shared_ptr<GRM::Element> GRM::Element::previousElementSibling()
 {
-  return previousElementSibling_impl();
+  return previousElementSiblingImpl();
 }
 
 std::shared_ptr<const GRM::Element> GRM::Element::previousElementSibling() const
 {
-  return previousElementSibling_impl();
+  return previousElementSiblingImpl();
 }
 
 std::shared_ptr<GRM::Element> GRM::Element::nextElementSibling()
 {
-  return nextElementSibling_impl();
+  return nextElementSiblingImpl();
 }
 
 std::shared_ptr<const GRM::Element> GRM::Element::nextElementSibling() const
 {
-  return nextElementSibling_impl();
+  return nextElementSiblingImpl();
 }
 
 std::vector<std::shared_ptr<GRM::Element>> GRM::Element::querySelectorsAll(const std::string &selectors)
 {
   std::vector<std::shared_ptr<GRM::Element>> found_elements;
   std::map<std::tuple<const GRM::Element *, const GRM::Selector *>, bool> match_map;
-  querySelectorsAll_impl(parseSelectors(selectors), found_elements, match_map);
+  querySelectorsAllImpl(parseSelectors(selectors), found_elements, match_map);
   return found_elements;
 }
 
@@ -390,18 +358,18 @@ std::vector<std::shared_ptr<const GRM::Element>> GRM::Element::querySelectorsAll
 {
   std::vector<std::shared_ptr<const GRM::Element>> found_elements;
   std::map<std::tuple<const GRM::Element *, const GRM::Selector *>, bool> match_map;
-  querySelectorsAll_impl(parseSelectors(selectors), found_elements, match_map);
+  querySelectorsAllImpl(parseSelectors(selectors), found_elements, match_map);
   return found_elements;
 }
 
 std::shared_ptr<GRM::Element> GRM::Element::querySelectors(const std::string &selectors)
 {
   std::map<std::tuple<const GRM::Element *, const GRM::Selector *>, bool> match_map;
-  return querySelectors_impl(parseSelectors(selectors), match_map);
+  return querySelectorsImpl(parseSelectors(selectors), match_map);
 }
 
 std::shared_ptr<const GRM::Element> GRM::Element::querySelectors(const std::string &selectors) const
 {
   std::map<std::tuple<const GRM::Element *, const GRM::Selector *>, bool> match_map;
-  return querySelectors_impl(parseSelectors(selectors), match_map);
+  return querySelectorsImpl(parseSelectors(selectors), match_map);
 }
